import { Construct } from "constructs";
import { TerraformBackend } from "../terraform-backend";
import { TerraformRemoteState, DataTerraformRemoteStateConfig } from "../terraform-remote-state";
export declare class EtcdBackend extends TerraformBackend {
    private readonly props;
    constructor(scope: Construct, props: EtcdBackendProps);
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    getRemoteStateDataSource(scope: Construct, name: string, _fromStack: string): TerraformRemoteState;
}
export declare class DataTerraformRemoteStateEtcd extends TerraformRemoteState {
    constructor(scope: Construct, id: string, config: DataTerraformRemoteStateEtcdConfig);
}
/**
 * Stores the state in etcd 2.x at a given path.
 *
 * This backend does not support state locking.
 *
 * Read more about this backend in the Terraform docs:
 * https://www.terraform.io/language/settings/backends/etcd
 */
export interface EtcdBackendProps {
    /**
     * (Required) The path where to store the state
     */
    readonly path: string;
    /**
     * (Required) A space-separated list of the etcd endpoints
     */
    readonly endpoints: string;
    /**
     * (Optional) The username
     */
    readonly username?: string;
    /**
     * (Optional) The password
     */
    readonly password?: string;
}
export interface DataTerraformRemoteStateEtcdConfig extends DataTerraformRemoteStateConfig, EtcdBackendProps {
}
